==> cloud-5.0.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/DetailActionButtonGroup.tsx <==
import { ACTION_BUTTON_ICON_LIST } from 'constant/others/other';
import EntityData from 'model/EntityData';
import EntityInfoTemplate from 'model/EntityInfoTemplate';
import { Form } from 'react-bootstrap';
import { useTranslation } from 'react-i18next';
import { Link } from 'react-router-dom';
import { getOperationsImpl } from 'service/convert';

const DetailActionButtonGroup = ({detailTemplate, cloudContext, entityData, entityId}: {
  detailTemplate: EntityInfoTemplate,
  cloudContext: string,
  entityData?: EntityData,
  entityId: string
}) => {

  const { t } = useTranslation();

  const operations = entityData
    ? getOperationsImpl(detailTemplate.cloudServiceProvider + '_' + detailTemplate.entityName, entityData.attributes)
      .map((label) => {
        return {
          action: label.toLowerCase().replaceAll(' ', '_'),
          label,
        };
      })
    : [];

  const operationActions = [
    { action: 'edit', label: 'Edit' },
    ...operations,
    { action: 'delete', label: 'Delete' },
  ];

  return <Form.Group className="mb-4">
    <Link className="btn btn-primary" to={`/${detailTemplate.cloudServiceProvider}/${cloudContext}/${detailTemplate.entityName}`}>
      <span className="glyphicon glyphicon-th-list"></span> {t(`List ${detailTemplate.cloudServiceProvider} ${detailTemplate.entityName}`)}
    </Link>
    {
      entityData
      ? operationActions.map((record) => {
          const to = `/${detailTemplate.cloudServiceProvider}/${cloudContext}/${detailTemplate.entityName}/${entityId}/${record.action}`;
          const iconInfo = ACTION_BUTTON_ICON_LIST.filter((r) => {
            return r.action === record.action;
          });
          const buttonColor = record.action !== 'delete'
            ? 'primary' : 'danger';
          return <Link className={`btn btn-${buttonColor}`} key={record.action} to={to}>
            {
              iconInfo.length >= 1
                ? <span className={`glyphicon glyphicon-${iconInfo[0].icon}`}></span>
                : <></>
            } {t(record.label)}
          </Link>;
        })
      : <></>
    }
  </Form.Group>;

}

export default DetailActionButtonGroup;

==> cloud-5.1.1.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/DetailActionButtonGroup.tsx <==
import { ACTION_BUTTON_ICON_LIST } from 'constant/others/other';
import useDrupalTranslation from 'hooks/drupal_translation';
import EntityData from 'model/EntityData';
import EntityInfoTemplate from 'model/EntityInfoTemplate';
import { Form } from 'react-bootstrap';
import { Link } from 'react-router-dom';
import { getOperationsImpl } from 'service/convert';
import { cspToLabel, entityNameToLabel } from 'service/string';

const DetailActionButtonGroup = ({detailTemplate, cloudContext, entityData, entityId}: {
  detailTemplate: EntityInfoTemplate,
  cloudContext: string,
  entityData?: EntityData,
  entityId: string
}) => {

  const { t } = useDrupalTranslation();

  const operations = entityData
    ? getOperationsImpl(detailTemplate.cloudServiceProvider + '_' + detailTemplate.entityName, entityData.attributes)
      .map((label) => {
        return {
          action: label.toLowerCase().replaceAll(' ', '_'),
          label,
        };
      })
    : [];

  const operationActions = [
    { action: 'edit', label: 'Edit' },
    ...operations,
    { action: 'delete', label: 'Delete' },
  ];

  return <Form.Group className="mb-4">
    <Link className="btn btn-primary" to={`/${detailTemplate.cloudServiceProvider}/${cloudContext}/${detailTemplate.entityName}`}>
      <span className="glyphicon glyphicon-th-list"></span> {
        Drupal.t('List @cloudServiceProvider @entityName', {
          '@cloudServiceProvider': cspToLabel(detailTemplate.cloudServiceProvider),
          '@entityName': entityNameToLabel(detailTemplate.entityName),
        })
      }
    </Link>
    {
      entityData
      ? operationActions.map((record) => {
          const to = `/${detailTemplate.cloudServiceProvider}/${cloudContext}/${detailTemplate.entityName}/${entityId}/${record.action}`;
          const iconInfo = ACTION_BUTTON_ICON_LIST.filter((r) => {
            return r.action === record.action;
          });
          const buttonColor = record.action !== 'delete'
            ? 'primary' : 'danger';
          return <Link className={`btn btn-${buttonColor}`} key={record.action} to={to}>
            {
              iconInfo.length >= 1
                ? <span className={`glyphicon glyphicon-${iconInfo[0].icon}`}></span>
                : <></>
            } {t(record.label)}
          </Link>;
        })
      : <></>
    }
  </Form.Group>;

}

export default DetailActionButtonGroup;
